@@ -36,12 +36,13 @@ class Client:
         headers = {'Content-Type': 'application/json'}
         payload = {"roomId": roomId, "messageData": { "description": messageData },"clientId":self.client_id}
         if type(messageData) is not str:
-            if bool(messageData.thumbnail) ^ bool(messageData.image):
-                if messageData.image:
-                    messageData.thumbnail = messageData.image
-                if messageData.thumbnail:
-                    messageData.image = messageData.thumbnail
-            payload = {"roomId": roomId, "messageData": json.loads(messageData.getJson()),"clientId":self.client_id}
+            messageDataLoads = json.loads(messageData.getJson())
+            if bool('thumbnail' in messageDataLoads.keys()) ^ bool('image' in messageDataLoads.keys()):
+                if 'image' in messageDataLoads.keys():
+                    messageDataLoads['thumbnail'] = messageDataLoads['image']
+                if 'thumbnail' in messageDataLoads.keys():
+                    messageDataLoads['image'] = messageDataLoads['thumbnail']
+            payload = {"roomId": roomId, "messageData": messageDataLoads,"clientId":self.client_id}
         response = requests.request("POST", url, headers=headers, json=payload)
         print('sendMessage',payload, response)
     
